@@ -52,7 +52,7 @@ struct _RsvgNodeTref {
 	RsvgNode * link;
 };
 char *
-rsvg_make_valid_utf8 (const char *str)
+rsvg_make_valid_utf8 (const char *str, int len)
 {
 	GString *string;
 	const char *remainder, *invalid;
@@ -60,8 +60,12 @@ rsvg_make_valid_utf8 (const char *str)
 	
 	string = NULL;
 	remainder = str;
-	remaining_bytes = strlen (str);
-	
+
+	if (len < 0)
+		remaining_bytes = strlen (str);
+	else
+		remaining_bytes = len;
+
 	while (remaining_bytes != 0)
 		{
 			if (g_utf8_validate (remainder, remaining_bytes, &invalid))
@@ -79,8 +83,8 @@ rsvg_make_valid_utf8 (const char *str)
 		}
 	
 	if (string == NULL) 
-		return g_strdup (str);
-	
+		return len < 0 ? g_strndup (str, len) : g_strdup (str);
+
 	g_string_append (string, remainder);
 	
 	return g_string_free (string, FALSE);
@@ -170,8 +174,9 @@ static void
 _rsvg_node_text_type_children(RsvgNode * self, RsvgDrawingCtx *ctx, 
 							  gdouble * x, gdouble * y, gboolean * lastwasspace)
 {
-	rsvg_push_discrete_layer(ctx);
 	guint i;
+
+	rsvg_push_discrete_layer(ctx);
 	for (i = 0; i < self->children->len; i++)
 		{
 			RsvgNode * node = g_ptr_array_index(self->children, i);
@@ -487,6 +492,18 @@ rsvg_text_get_pango_context (RsvgDrawingCtx *ctx)
 	
 	context = pango_ft2_font_map_create_context (fontmap);
 	g_object_unref (fontmap);
+
+  /*  Workaround for bug #143542 (PangoFT2Fontmap leak),
+   *  see also bug #344235 (Text layer rendering leaks font file descriptor):
+   *
+   *  Calling pango_ft2_font_map_substitute_changed() causes the
+   *  font_map cache to be flushed, thereby removing the circular
+   *  reference that causes the leak.
+   */
+  g_object_weak_ref (G_OBJECT(context),
+                     (GWeakNotify) pango_ft2_font_map_substitute_changed,
+                     fontmap);
+
 	
 	return context;
 }
@@ -590,7 +607,7 @@ rsvg_text_vector_coords (RenderCtx       *ctx,
 }
 
 static gint
-moveto (FT_Vector *to,
+moveto (const FT_Vector *to,
 		gpointer   data)
 {
 	RenderCtx * ctx;
@@ -616,7 +633,7 @@ moveto (FT_Vector *to,
 }
 
 static gint
-lineto (FT_Vector *to,
+lineto (const FT_Vector *to,
 		gpointer   data)
 {
 	RenderCtx * ctx;
@@ -640,8 +657,8 @@ lineto (FT_Vector *to,
 }
 
 static gint
-conicto (FT_Vector *ftcontrol,
-		 FT_Vector *to,
+conicto (const FT_Vector *ftcontrol,
+		 const FT_Vector *to,
 		 gpointer   data)
 {
 	RenderCtx * ctx;
@@ -671,9 +688,9 @@ conicto (FT_Vector *ftcontrol,
 }
 
 static gint
-cubicto (FT_Vector *ftcontrol1,
-		 FT_Vector *ftcontrol2,
-		 FT_Vector *to,
+cubicto (const FT_Vector *ftcontrol1,
+		 const FT_Vector *ftcontrol2,
+		 const FT_Vector *to,
 		 gpointer   data)
 {
 	RenderCtx * ctx;
@@ -752,10 +769,10 @@ rsvg_text_render_vectors (PangoFont     *font,
 {
 	static const FT_Outline_Funcs outline_funcs =
 		{
-			moveto,
-			lineto,
-			conicto,
-			cubicto,
+			(FT_Outline_MoveToFunc)moveto,
+			(FT_Outline_LineToFunc)lineto,
+			(FT_Outline_ConicToFunc)conicto,
+			(FT_Outline_CubicToFunc)cubicto,
 			0,
 			0
 		};
